==> huaweicloudsdkcph-3.1.8-py2.py3-none-any.whl: huaweicloudsdkcph/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request import BatchExportCloudPhoneDataRequest
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request_body import BatchExportCloudPhoneDataRequestBody
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request_body_storage_infos import BatchExportCloudPhoneDataRequestBodyStorageInfos
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_response import BatchExportCloudPhoneDataResponse
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request import BatchImportCloudPhoneDataRequest
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request_body import BatchImportCloudPhoneDataRequestBody
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request_body_restore_infos import BatchImportCloudPhoneDataRequestBodyRestoreInfos
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_response import BatchImportCloudPhoneDataResponse
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request import BatchMigrateCloudPhoneRequest
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request_body import BatchMigrateCloudPhoneRequestBody
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request_body_migrate_infos import BatchMigrateCloudPhoneRequestBodyMigrateInfos
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_response import BatchMigrateCloudPhoneResponse
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request import ChangeCloudPhoneServerModelRequest
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request_body import ChangeCloudPhoneServerModelRequestBody
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request_body_extend_param import ChangeCloudPhoneServerModelRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_response import ChangeCloudPhoneServerModelResponse
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request import CreateCloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body import CreateCloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_band_width import CreateCloudPhoneServerRequestBodyBandWidth
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_extend_param import CreateCloudPhoneServerRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_ports import CreateCloudPhoneServerRequestBodyPorts
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_response import CreateCloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request import CreateNet2CloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body import CreateNet2CloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_band_width import CreateNet2CloudPhoneServerRequestBodyBandWidth
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_extend_param import CreateNet2CloudPhoneServerRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_nics import CreateNet2CloudPhoneServerRequestBodyNics
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_ports import CreateNet2CloudPhoneServerRequestBodyPorts
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_public_ip import CreateNet2CloudPhoneServerRequestBodyPublicIp
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_public_ip_eip import CreateNet2CloudPhoneServerRequestBodyPublicIpEip
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_response import CreateNet2CloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.delete_share_apps_request import DeleteShareAppsRequest
from huaweicloudsdkcph.v1.model.delete_share_apps_request_body import DeleteShareAppsRequestBody
from huaweicloudsdkcph.v1.model.delete_share_apps_response import DeleteShareAppsResponse
from huaweicloudsdkcph.v1.model.import_traffic_request import ImportTrafficRequest
from huaweicloudsdkcph.v1.model.import_traffic_request_body import ImportTrafficRequestBody
from huaweicloudsdkcph.v1.model.import_traffic_response import ImportTrafficResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_images_request import ListCloudPhoneImagesRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_images_response import ListCloudPhoneImagesResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_models_request import ListCloudPhoneModelsRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_models_response import ListCloudPhoneModelsResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_server_models_request import ListCloudPhoneServerModelsRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_server_models_response import ListCloudPhoneServerModelsResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_servers_request import ListCloudPhoneServersRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_servers_response import ListCloudPhoneServersResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_servers_response_body import ListCloudPhoneServersResponseBody
from huaweicloudsdkcph.v1.model.list_cloud_phones_request import ListCloudPhonesRequest
from huaweicloudsdkcph.v1.model.list_cloud_phones_response import ListCloudPhonesResponse
from huaweicloudsdkcph.v1.model.list_encode_servers_request import ListEncodeServersRequest
from huaweicloudsdkcph.v1.model.list_encode_servers_response import ListEncodeServersResponse
from huaweicloudsdkcph.v1.model.list_jobs_request import ListJobsRequest
from huaweicloudsdkcph.v1.model.list_jobs_response import ListJobsResponse
from huaweicloudsdkcph.v1.model.list_share_files_request import ListShareFilesRequest
from huaweicloudsdkcph.v1.model.list_share_files_response import ListShareFilesResponse
from huaweicloudsdkcph.v1.model.phones import Phones
from huaweicloudsdkcph.v1.model.phones_phones import PhonesPhones
from huaweicloudsdkcph.v1.model.push_share_apps_request import PushShareAppsRequest
from huaweicloudsdkcph.v1.model.push_share_apps_request_body import PushShareAppsRequestBody
from huaweicloudsdkcph.v1.model.push_share_apps_response import PushShareAppsResponse
from huaweicloudsdkcph.v1.model.push_share_files_request import PushShareFilesRequest
from huaweicloudsdkcph.v1.model.push_share_files_request_body import PushShareFilesRequestBody
from huaweicloudsdkcph.v1.model.push_share_files_response import PushShareFilesResponse
from huaweicloudsdkcph.v1.model.request_id_response_body import RequestIdResponseBody
from huaweicloudsdkcph.v1.model.reset_cloud_phone_request import ResetCloudPhoneRequest
from huaweicloudsdkcph.v1.model.reset_cloud_phone_response import ResetCloudPhoneResponse
from huaweicloudsdkcph.v1.model.reset_restart_request_body import ResetRestartRequestBody
from huaweicloudsdkcph.v1.model.reset_restart_request_body_phones import ResetRestartRequestBodyPhones
from huaweicloudsdkcph.v1.model.restart_cloud_phone_request import RestartCloudPhoneRequest
from huaweicloudsdkcph.v1.model.restart_cloud_phone_response import RestartCloudPhoneResponse
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_request import RestartCloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_request_body import RestartCloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_response import RestartCloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.restart_encode_server_request import RestartEncodeServerRequest
from huaweicloudsdkcph.v1.model.restart_encode_server_request_body import RestartEncodeServerRequestBody
from huaweicloudsdkcph.v1.model.restart_encode_server_response import RestartEncodeServerResponse
from huaweicloudsdkcph.v1.model.run_shell_command_request import RunShellCommandRequest
from huaweicloudsdkcph.v1.model.run_shell_command_request_body import RunShellCommandRequestBody
from huaweicloudsdkcph.v1.model.run_shell_command_response import RunShellCommandResponse
from huaweicloudsdkcph.v1.model.run_sync_command_request import RunSyncCommandRequest
from huaweicloudsdkcph.v1.model.run_sync_command_request_body import RunSyncCommandRequestBody
from huaweicloudsdkcph.v1.model.run_sync_command_response import RunSyncCommandResponse
from huaweicloudsdkcph.v1.model.show_bandwidth_detail_request import ShowBandwidthDetailRequest
from huaweicloudsdkcph.v1.model.show_bandwidth_detail_response import ShowBandwidthDetailResponse
from huaweicloudsdkcph.v1.model.show_cloud_phone_detail_request import ShowCloudPhoneDetailRequest
from huaweicloudsdkcph.v1.model.show_cloud_phone_detail_response import ShowCloudPhoneDetailResponse
from huaweicloudsdkcph.v1.model.show_cloud_phone_server_detail_request import ShowCloudPhoneServerDetailRequest
from huaweicloudsdkcph.v1.model.show_cloud_phone_server_detail_response import ShowCloudPhoneServerDetailResponse
from huaweicloudsdkcph.v1.model.show_job_request import ShowJobRequest
from huaweicloudsdkcph.v1.model.show_job_response import ShowJobResponse
from huaweicloudsdkcph.v1.model.stop_cloud_phone_request import StopCloudPhoneRequest
from huaweicloudsdkcph.v1.model.stop_cloud_phone_request_body import StopCloudPhoneRequestBody
from huaweicloudsdkcph.v1.model.stop_cloud_phone_response import StopCloudPhoneResponse
from huaweicloudsdkcph.v1.model.update_bandwidth_request import UpdateBandwidthRequest
from huaweicloudsdkcph.v1.model.update_bandwidth_request_body import UpdateBandwidthRequestBody
from huaweicloudsdkcph.v1.model.update_bandwidth_response import UpdateBandwidthResponse
from huaweicloudsdkcph.v1.model.update_cloud_phone_property_request import UpdateCloudPhonePropertyRequest
from huaweicloudsdkcph.v1.model.update_cloud_phone_property_response import UpdateCloudPhonePropertyResponse
from huaweicloudsdkcph.v1.model.update_keypair_request import UpdateKeypairRequest
from huaweicloudsdkcph.v1.model.update_keypair_request_body import UpdateKeypairRequestBody
from huaweicloudsdkcph.v1.model.update_keypair_request_body_servers import UpdateKeypairRequestBodyServers
from huaweicloudsdkcph.v1.model.update_keypair_response import UpdateKeypairResponse
from huaweicloudsdkcph.v1.model.update_phone_name_request import UpdatePhoneNameRequest
from huaweicloudsdkcph.v1.model.update_phone_name_request_body import UpdatePhoneNameRequestBody
from huaweicloudsdkcph.v1.model.update_phone_name_response import UpdatePhoneNameResponse
from huaweicloudsdkcph.v1.model.update_server_name_request import UpdateServerNameRequest
from huaweicloudsdkcph.v1.model.update_server_name_request_body import UpdateServerNameRequestBody
from huaweicloudsdkcph.v1.model.update_server_name_response import UpdateServerNameResponse

==> huaweicloudsdkcph-3.1.12-py2.py3-none-any.whl: huaweicloudsdkcph/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkcph.v1.model.address import Address
from huaweicloudsdkcph.v1.model.bandwidth import Bandwidth
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request import BatchExportCloudPhoneDataRequest
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request_body import BatchExportCloudPhoneDataRequestBody
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_request_body_storage_infos import BatchExportCloudPhoneDataRequestBodyStorageInfos
from huaweicloudsdkcph.v1.model.batch_export_cloud_phone_data_response import BatchExportCloudPhoneDataResponse
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request import BatchImportCloudPhoneDataRequest
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request_body import BatchImportCloudPhoneDataRequestBody
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_request_body_restore_infos import BatchImportCloudPhoneDataRequestBodyRestoreInfos
from huaweicloudsdkcph.v1.model.batch_import_cloud_phone_data_response import BatchImportCloudPhoneDataResponse
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request import BatchMigrateCloudPhoneRequest
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request_body import BatchMigrateCloudPhoneRequestBody
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_request_body_migrate_infos import BatchMigrateCloudPhoneRequestBodyMigrateInfos
from huaweicloudsdkcph.v1.model.batch_migrate_cloud_phone_response import BatchMigrateCloudPhoneResponse
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request import ChangeCloudPhoneServerModelRequest
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request_body import ChangeCloudPhoneServerModelRequestBody
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_request_body_extend_param import ChangeCloudPhoneServerModelRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.change_cloud_phone_server_model_response import ChangeCloudPhoneServerModelResponse
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request import CreateCloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body import CreateCloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_band_width import CreateCloudPhoneServerRequestBodyBandWidth
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_extend_param import CreateCloudPhoneServerRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_request_body_ports import CreateCloudPhoneServerRequestBodyPorts
from huaweicloudsdkcph.v1.model.create_cloud_phone_server_response import CreateCloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request import CreateNet2CloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body import CreateNet2CloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_band_width import CreateNet2CloudPhoneServerRequestBodyBandWidth
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_extend_param import CreateNet2CloudPhoneServerRequestBodyExtendParam
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_nics import CreateNet2CloudPhoneServerRequestBodyNics
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_ports import CreateNet2CloudPhoneServerRequestBodyPorts
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_public_ip import CreateNet2CloudPhoneServerRequestBodyPublicIp
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_request_body_public_ip_eip import CreateNet2CloudPhoneServerRequestBodyPublicIpEip
from huaweicloudsdkcph.v1.model.create_net2_cloud_phone_server_response import CreateNet2CloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.delete_share_apps_request import DeleteShareAppsRequest
from huaweicloudsdkcph.v1.model.delete_share_apps_request_body import DeleteShareAppsRequestBody
from huaweicloudsdkcph.v1.model.delete_share_apps_response import DeleteShareAppsResponse
from huaweicloudsdkcph.v1.model.delete_share_files_request import DeleteShareFilesRequest
from huaweicloudsdkcph.v1.model.delete_share_files_request_body import DeleteShareFilesRequestBody
from huaweicloudsdkcph.v1.model.delete_share_files_response import DeleteShareFilesResponse
from huaweicloudsdkcph.v1.model.import_traffic_request import ImportTrafficRequest
from huaweicloudsdkcph.v1.model.import_traffic_request_body import ImportTrafficRequestBody
from huaweicloudsdkcph.v1.model.import_traffic_response import ImportTrafficResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_images_request import ListCloudPhoneImagesRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_images_response import ListCloudPhoneImagesResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_models_request import ListCloudPhoneModelsRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_models_response import ListCloudPhoneModelsResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_server_models_request import ListCloudPhoneServerModelsRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_server_models_response import ListCloudPhoneServerModelsResponse
from huaweicloudsdkcph.v1.model.list_cloud_phone_servers_request import ListCloudPhoneServersRequest
from huaweicloudsdkcph.v1.model.list_cloud_phone_servers_response import ListCloudPhoneServersResponse
from huaweicloudsdkcph.v1.model.list_cloud_phones_request import ListCloudPhonesRequest
from huaweicloudsdkcph.v1.model.list_cloud_phones_response import ListCloudPhonesResponse
from huaweicloudsdkcph.v1.model.list_encode_servers_request import ListEncodeServersRequest
from huaweicloudsdkcph.v1.model.list_encode_servers_response import ListEncodeServersResponse
from huaweicloudsdkcph.v1.model.list_jobs_request import ListJobsRequest
from huaweicloudsdkcph.v1.model.list_jobs_response import ListJobsResponse
from huaweicloudsdkcph.v1.model.list_share_files_request import ListShareFilesRequest
from huaweicloudsdkcph.v1.model.list_share_files_response import ListShareFilesResponse
from huaweicloudsdkcph.v1.model.phones import Phones
from huaweicloudsdkcph.v1.model.phones_phones import PhonesPhones
from huaweicloudsdkcph.v1.model.push_share_apps_request import PushShareAppsRequest
from huaweicloudsdkcph.v1.model.push_share_apps_request_body import PushShareAppsRequestBody
from huaweicloudsdkcph.v1.model.push_share_apps_response import PushShareAppsResponse
from huaweicloudsdkcph.v1.model.push_share_files_request import PushShareFilesRequest
from huaweicloudsdkcph.v1.model.push_share_files_request_body import PushShareFilesRequestBody
from huaweicloudsdkcph.v1.model.push_share_files_response import PushShareFilesResponse
from huaweicloudsdkcph.v1.model.request_id_response_body import RequestIdResponseBody
from huaweicloudsdkcph.v1.model.reset_cloud_phone_request import ResetCloudPhoneRequest
from huaweicloudsdkcph.v1.model.reset_cloud_phone_response import ResetCloudPhoneResponse
from huaweicloudsdkcph.v1.model.reset_restart_request_body import ResetRestartRequestBody
from huaweicloudsdkcph.v1.model.reset_restart_request_body_phones import ResetRestartRequestBodyPhones
from huaweicloudsdkcph.v1.model.restart_cloud_phone_request import RestartCloudPhoneRequest
from huaweicloudsdkcph.v1.model.restart_cloud_phone_response import RestartCloudPhoneResponse
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_request import RestartCloudPhoneServerRequest
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_request_body import RestartCloudPhoneServerRequestBody
from huaweicloudsdkcph.v1.model.restart_cloud_phone_server_response import RestartCloudPhoneServerResponse
from huaweicloudsdkcph.v1.model.restart_encode_server_request import RestartEncodeServerRequest
from huaweicloudsdkcph.v1.model.restart_encode_server_request_body import RestartEncodeServerRequestBody
from huaweicloudsdkcph.v1.model.restart_encode_server_response import RestartEncodeServerResponse
from huaweicloudsdkcph.v1.model.run_shell_command_request import RunShellCommandRequest
from huaweicloudsdkcph.v1.model.run_shell_command_request_body import RunShellCommandRequestBody
from huaweicloudsdkcph.v1.model.run_shell_command_response import RunShellCommandResponse
from huaweicloudsdkcph.v1.model.run_sync_command_request import RunSyncCommandRequest
from huaweicloudsdkcph.v1.model.run_sync_command_request_body import RunSyncCommandRequestBody
from huaweicloudsdkcph.v1.model.run_sync_command_response import RunSyncCommandResponse
from huaweicloudsdkcph.v1.model.show_bandwidth_detail_request import ShowBandwidthDetailRequest
from huaweicloudsdkcph.v1.model.show_bandwidth_detail_response import ShowBandwidthDetailResponse
from huaweicloudsdkcph.v1.model.show_cloud_phone_detail_request import ShowCloudPhoneDetailRequest
from huaweicloudsdkcph.v1.model.show_cloud_phone_detail_response import ShowCloudPhoneDetailResponse
from huaweicloudsdkcph.v1.model.show_cloud_phone_server_detail_request import ShowCloudPhoneServerDetailRequest
from huaweicloudsdkcph.v1.model.show_cloud_phone_server_detail_response import ShowCloudPhoneServerDetailResponse
from huaweicloudsdkcph.v1.model.show_job_request import ShowJobRequest
from huaweicloudsdkcph.v1.model.show_job_response import ShowJobResponse
from huaweicloudsdkcph.v1.model.stop_cloud_phone_request import StopCloudPhoneRequest
from huaweicloudsdkcph.v1.model.stop_cloud_phone_request_body import StopCloudPhoneRequestBody
from huaweicloudsdkcph.v1.model.stop_cloud_phone_response import StopCloudPhoneResponse
from huaweicloudsdkcph.v1.model.update_bandwidth_request import UpdateBandwidthRequest
from huaweicloudsdkcph.v1.model.update_bandwidth_request_body import UpdateBandwidthRequestBody
from huaweicloudsdkcph.v1.model.update_bandwidth_response import UpdateBandwidthResponse
from huaweicloudsdkcph.v1.model.update_cloud_phone_property_request import UpdateCloudPhonePropertyRequest
from huaweicloudsdkcph.v1.model.update_cloud_phone_property_response import UpdateCloudPhonePropertyResponse
from huaweicloudsdkcph.v1.model.update_keypair_request import UpdateKeypairRequest
from huaweicloudsdkcph.v1.model.update_keypair_request_body import UpdateKeypairRequestBody
from huaweicloudsdkcph.v1.model.update_keypair_request_body_servers import UpdateKeypairRequestBodyServers
from huaweicloudsdkcph.v1.model.update_keypair_response import UpdateKeypairResponse
from huaweicloudsdkcph.v1.model.update_phone_name_request import UpdatePhoneNameRequest
from huaweicloudsdkcph.v1.model.update_phone_name_request_body import UpdatePhoneNameRequestBody
from huaweicloudsdkcph.v1.model.update_phone_name_response import UpdatePhoneNameResponse
from huaweicloudsdkcph.v1.model.update_server_name_request import UpdateServerNameRequest
from huaweicloudsdkcph.v1.model.update_server_name_request_body import UpdateServerNameRequestBody
from huaweicloudsdkcph.v1.model.update_server_name_response import UpdateServerNameResponse
from huaweicloudsdkcph.v1.model.volume import Volume
